@@ -22,26 +22,40 @@ from unittest.mock import patch
 
 import pytest
 
-from airflow.models import DAG, DagRun, TaskInstance
-from airflow.models.serialized_dag import SerializedDagModel
+from airflow.models import DagRun, TaskInstance
+from airflow.providers.common.compat.sdk import timezone
 from airflow.providers.redis.log.redis_task_handler import RedisTaskHandler
 from airflow.providers.standard.operators.empty import EmptyOperator
 from airflow.utils.session import create_session
 from airflow.utils.state import State
-from airflow.utils.timezone import datetime
 
 from tests_common.test_utils.config import conf_vars
+from tests_common.test_utils.dag import sync_dag_to_db
+from tests_common.test_utils.db import clear_db_dag_bundles, clear_db_dags, clear_db_runs
 from tests_common.test_utils.file_task_handler import extract_events
 from tests_common.test_utils.version_compat import (
     AIRFLOW_V_3_0_PLUS,
+    AIRFLOW_V_3_1_PLUS,
     get_base_airflow_version_tuple,
 )
 
+if AIRFLOW_V_3_1_PLUS:
+    from airflow.sdk import DAG
+else:
+    from airflow.models import DAG
+
 
 class TestRedisTaskHandler:
+    @staticmethod
+    def clear_db():
+        clear_db_dags()
+        clear_db_runs()
+        if AIRFLOW_V_3_0_PLUS:
+            clear_db_dag_bundles()
+
     @pytest.fixture
     def ti(self):
-        date = datetime(2020, 1, 1)
+        date = timezone.datetime(2020, 1, 1)
         dag = DAG(dag_id="dag_for_testing_redis_task_handler", schedule=None, start_date=date)
         task = EmptyOperator(task_id="task_for_testing_redis_log_handler", dag=dag)
         if AIRFLOW_V_3_0_PLUS:
@@ -64,14 +78,25 @@ class TestRedisTaskHandler:
         dag_run.set_state(State.RUNNING)
         with create_session() as session:
             session.add(dag_run)
-            session.commit()
+            session.flush()
             session.refresh(dag_run)
 
+            bundle_name = "testing"
+            if AIRFLOW_V_3_1_PLUS:
+                sync_dag_to_db(dag, bundle_name=bundle_name, session=session)
+            elif AIRFLOW_V_3_0_PLUS:
+                from airflow.models.dagbundle import DagBundleModel
+                from airflow.models.serialized_dag import SerializedDagModel
+                from airflow.serialization.serialized_objects import SerializedDAG
+
+                session.add(DagBundleModel(name=bundle_name))
+                session.flush()
+                SerializedDAG.bulk_write_to_db(bundle_name, None, [dag])
+                SerializedDagModel.write_dag(dag, bundle_name=bundle_name)
+
         if AIRFLOW_V_3_0_PLUS:
             from airflow.models.dag_version import DagVersion
 
-            dag.sync_to_db()
-            SerializedDagModel.write_dag(dag, bundle_name="testing")
             dag_version = DagVersion.get_latest_version(dag.dag_id)
             ti = TaskInstance(task=task, run_id=dag_run.run_id, dag_version_id=dag_version.id)
         else:
@@ -82,8 +107,7 @@ class TestRedisTaskHandler:
 
         yield ti
 
-        with create_session() as session:
-            session.query(DagRun).delete()
+        self.clear_db()
 
     @pytest.mark.db_test
     @conf_vars({("logging", "remote_log_conn_id"): "redis_default"})
@@ -124,7 +148,7 @@ class TestRedisTaskHandler:
             logs = handler.read(ti)
 
         if AIRFLOW_V_3_0_PLUS:
-            if get_base_airflow_version_tuple() < (3, 1, 0):
+            if get_base_airflow_version_tuple() < (3, 0, 4):
                 assert logs == (["Line 1\nLine 2"], {"end_of_log": True})
             else:
                 log_stream, metadata = logs
